"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const logger = require("../../../helpers/logger.qwik.cjs");
const set = require("../../set.qwik.cjs");
const helpers = require("../helpers.qwik.cjs");
const acornInterpreter = require("./acorn-interpreter.qwik.cjs");
const processCode = (code) => {
  return code.split("\n").map((line) => {
    const trimmed = line.trim();
    if (line.includes("__awaiter"))
      return void 0;
    const isStateSetter = trimmed.startsWith("state.");
    if (!isStateSetter)
      return line;
    const [lhs, rhs] = trimmed.split("=");
    const setStr = lhs.replace("state.", "").trim();
    const setExpr = `setRootState('${setStr}', ${rhs.trim()})`;
    return `
  ${line}
  ${setExpr}
  `;
  }).filter(Boolean).join("\n");
};
const getJSONValName = (val) => val + "JSON";
const runInEdge = ({ builder, context, event, rootState, localState, rootSetState, code }) => {
  const state = {
    ...rootState,
    ...localState
  };
  const properties = helpers.getFunctionArguments({
    builder,
    context,
    event,
    state
  });
  const prependedCode = properties.map(([key]) => {
    const jsonValName = getJSONValName(key);
    return `var ${key} = ${jsonValName} === undefined ? undefined : JSON.parse(${jsonValName});`;
  }).join("\n");
  const cleanedCode = processCode(code);
  if (cleanedCode === "") {
    logger.logger.warn("Skipping evaluation of empty code block.");
    return;
  }
  const transformed = `
function theFunction() {
  ${prependedCode}

  ${cleanedCode}
}
theFunction();
`;
  const setRootState = (prop, value) => {
    const newState = set.set(state, prop, value);
    rootSetState == null ? void 0 : rootSetState(newState);
  };
  const initFunc = function(interpreter, globalObject) {
    properties.forEach(([key, val]) => {
      const jsonVal = JSON.stringify(val);
      interpreter.setProperty(globalObject, getJSONValName(key), jsonVal);
    });
    interpreter.setProperty(globalObject, "setRootState", interpreter.createNativeFunction(setRootState));
  };
  const myInterpreter = new acornInterpreter(transformed, initFunc);
  myInterpreter.run();
  const output = myInterpreter.pseudoToNative(myInterpreter.value);
  return output;
};
exports.runInEdge = runInEdge;
